@@ -101,13 +101,8 @@ class RuntimeEntryData:
     ) -> None:
         async with self.platform_load_lock:
             needed = platforms - self.loaded_platforms
-            tasks = []
-            for platform in needed:
-                tasks.append(
-                    hass.config_entries.async_forward_entry_setup(entry, platform)
-                )
-            if tasks:
-                await asyncio.wait(tasks)
+            if needed:
+                await hass.config_entries.async_forward_entry_setups(entry, needed)
             self.loaded_platforms |= needed
 
     async def async_update_static_infos(
