@@ -8,6 +8,7 @@ from datetime import timedelta
 from enum import Enum
 import itertools
 import logging
+import re
 import time
 import traceback
 from typing import TYPE_CHECKING, Any, NamedTuple, Union
@@ -20,6 +21,7 @@ import zigpy.endpoint
 import zigpy.group
 from zigpy.types.named import EUI64
 
+from homeassistant import __path__ as HOMEASSISTANT_PATH
 from homeassistant.components.system_log import LogEntry, _figure_out_source
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.core import HomeAssistant, callback
@@ -27,7 +29,6 @@ from homeassistant.exceptions import ConfigEntryNotReady
 from homeassistant.helpers import device_registry as dr, entity_registry as er
 from homeassistant.helpers.dispatcher import async_dispatcher_send
 from homeassistant.helpers.entity import DeviceInfo
-from homeassistant.helpers.event import async_track_time_interval
 from homeassistant.helpers.typing import ConfigType
 
 from . import discovery
@@ -81,14 +82,12 @@ from .const import (
 from .device import DeviceStatus, ZHADevice
 from .group import GroupMember, ZHAGroup
 from .registries import GROUP_ENTITY_DOMAINS
-from .store import async_get_registry
 
 if TYPE_CHECKING:
     from logging import Filter, LogRecord
 
     from ..entity import ZhaEntity
     from .channels.base import ZigbeeChannel
-    from .store import ZhaStorage
 
     _LogFilterType = Union[Filter, Callable[[LogRecord], int]]
 
@@ -118,7 +117,6 @@ class ZHAGateway:
     """Gateway that handles events that happen on the ZHA Zigbee network."""
 
     # -- Set in async_initialize --
-    zha_storage: ZhaStorage
     ha_device_registry: dr.DeviceRegistry
     ha_entity_registry: er.EntityRegistry
     application_controller: ControllerApplication
@@ -144,13 +142,13 @@ class ZHAGateway:
         self._log_relay_handler = LogRelayHandler(hass, self)
         self.config_entry = config_entry
         self._unsubs: list[Callable[[], None]] = []
+        self.initialized: bool = False
 
     async def async_initialize(self) -> None:
         """Initialize controller and connect radio."""
         discovery.PROBE.initialize(self._hass)
         discovery.GROUP_PROBE.initialize(self._hass)
 
-        self.zha_storage = await async_get_registry(self._hass)
         self.ha_device_registry = dr.async_get(self._hass)
         self.ha_entity_registry = er.async_get(self._hass)
 
@@ -183,23 +181,21 @@ class ZHAGateway:
         self.application_controller.add_listener(self)
         self.application_controller.groups.add_listener(self)
         self._hass.data[DATA_ZHA][DATA_ZHA_GATEWAY] = self
-        self._hass.data[DATA_ZHA][DATA_ZHA_BRIDGE_ID] = str(
-            self.application_controller.ieee
-        )
+        self._hass.data[DATA_ZHA][DATA_ZHA_BRIDGE_ID] = str(self.coordinator_ieee)
         self.async_load_devices()
         self.async_load_groups()
+        self.initialized = True
 
     @callback
     def async_load_devices(self) -> None:
         """Restore ZHA devices from zigpy application state."""
         for zigpy_device in self.application_controller.devices.values():
             zha_device = self._async_get_or_create_device(zigpy_device, restored=True)
-            if zha_device.ieee == self.application_controller.ieee:
+            if zha_device.ieee == self.coordinator_ieee:
                 self.coordinator_zha_device = zha_device
-            zha_dev_entry = self.zha_storage.devices.get(str(zigpy_device.ieee))
             delta_msg = "not known"
-            if zha_dev_entry and zha_dev_entry.last_seen is not None:
-                delta = round(time.time() - zha_dev_entry.last_seen)
+            if zha_device.last_seen is not None:
+                delta = round(time.time() - zha_device.last_seen)
                 zha_device.available = delta < zha_device.consider_unavailable_time
                 delta_msg = f"{str(timedelta(seconds=delta))} ago"
             _LOGGER.debug(
@@ -210,13 +206,6 @@ class ZHAGateway:
                 delta_msg,
                 zha_device.consider_unavailable_time,
             )
-        # update the last seen time for devices every 10 minutes to avoid thrashing
-        # writes and shutdown issues where storage isn't updated
-        self._unsubs.append(
-            async_track_time_interval(
-                self._hass, self.async_update_device_storage, timedelta(minutes=10)
-            )
-        )
 
     @callback
     def async_load_groups(self) -> None:
@@ -230,7 +219,7 @@ class ZHAGateway:
     async def async_initialize_devices_and_entities(self) -> None:
         """Initialize devices and load entities."""
 
-        _LOGGER.debug("Loading all devices")
+        _LOGGER.debug("Initializing all devices from Zigpy cache")
         await asyncio.gather(
             *(dev.async_initialize(from_cache=True) for dev in self.devices.values())
         )
@@ -448,6 +437,11 @@ class ZHAGateway:
             )
             self.ha_entity_registry.async_remove(entry.entity_id)
 
+    @property
+    def coordinator_ieee(self) -> EUI64:
+        """Return the active coordinator's IEEE address."""
+        return self.application_controller.state.node_info.ieee
+
     @property
     def devices(self) -> dict[EUI64, ZHADevice]:
         """Return devices."""
@@ -526,8 +520,6 @@ class ZHAGateway:
                 model=zha_device.model,
             )
             zha_device.set_device_id(device_registry_device.id)
-        entry = self.zha_storage.async_get_or_create_device(zha_device)
-        zha_device.async_update_last_seen(entry.last_seen)
         return zha_device
 
     @callback
@@ -550,17 +542,9 @@ class ZHAGateway:
             if device.status is DeviceStatus.INITIALIZED:
                 device.update_available(available)
 
-    async def async_update_device_storage(self, *_: Any) -> None:
-        """Update the devices in the store."""
-        for device in self.devices.values():
-            self.zha_storage.async_update_device(device)
-
     async def async_device_initialized(self, device: zigpy.device.Device) -> None:
         """Handle device joined and basic information discovered (async)."""
         zha_device = self._async_get_or_create_device(device)
-        # This is an active device so set a last seen if it is none
-        if zha_device.last_seen is None:
-            zha_device.async_update_last_seen(time.time())
         _LOGGER.debug(
             "device - %s:%s entering async_device_initialized - is_new_join: %s",
             device.nwk,
@@ -752,7 +736,15 @@ class LogRelayHandler(logging.Handler):
         if record.levelno >= logging.WARN and not record.exc_info:
             stack = [f for f, _, _, _ in traceback.extract_stack()]
 
-        entry = LogEntry(record, stack, _figure_out_source(record, stack, self.hass))
+        hass_path: str = HOMEASSISTANT_PATH[0]
+        config_dir = self.hass.config.config_dir
+        assert config_dir is not None
+        paths_re = re.compile(
+            r"(?:{})/(.*)".format(
+                "|".join([re.escape(x) for x in (hass_path, config_dir)])
+            )
+        )
+        entry = LogEntry(record, stack, _figure_out_source(record, stack, paths_re))
         async_dispatcher_send(
             self.hass,
             ZHA_GW_MSG,
